@@ -1,5 +1,5 @@
 from django_fake_model import models as f
-from ..models import SoftDeletes, Timestampable
+from timestamps.models import SoftDeletes, Timestampable
 
 
 class FooTimestamps(f.FakeModel, Timestampable):
